/* PIKA - Photo and Image Kooker Application
 * a rebranding of The GNU Image Manipulation Program (created with heckimp)
 * A derived work which may be trivial. However, any changes may be (C)2023 by Aldercone Studio
 *
 * Original copyright, applying to most contents (license remains unchanged): 
 * Copyright (C) 1995-2003 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

/* NOTE: This file is auto-generated by pdbgen.pl. */

#include "config.h"

#include "stamp-pdbgen.h"

#include <gegl.h>

#include <gdk-pixbuf/gdk-pixbuf.h>

#include "libpikabase/pikabase.h"

#include "pdb-types.h"

#include "core/pika.h"
#include "core/pikadatafactory.h"
#include "core/pikadrawable.h"
#include "core/pikaparamspecs.h"

#include "pikapdb.h"
#include "pikaprocedure.h"
#include "internal-procs.h"


static PikaValueArray *
drawables_popup_invoker (PikaProcedure         *procedure,
                         Pika                  *pika,
                         PikaContext           *context,
                         PikaProgress          *progress,
                         const PikaValueArray  *args,
                         GError               **error)
{
  gboolean success = TRUE;
  const gchar *callback;
  const gchar *popup_title;
  const gchar *drawable_type;
  PikaDrawable *initial_drawable;
  GBytes *parent_window;

  callback = g_value_get_string (pika_value_array_index (args, 0));
  popup_title = g_value_get_string (pika_value_array_index (args, 1));
  drawable_type = g_value_get_string (pika_value_array_index (args, 2));
  initial_drawable = g_value_get_object (pika_value_array_index (args, 3));
  parent_window = g_value_get_boxed (pika_value_array_index (args, 4));

  if (success)
    {
      if (pika->no_interface ||
          ! pika_pdb_lookup_procedure (pika->pdb, callback) ||
          ! pika_pdb_dialog_new (pika, context, progress,
                                 g_type_from_name (drawable_type),
                                 parent_window, popup_title, callback,
                                 PIKA_OBJECT (initial_drawable),
                                 NULL))
        success = FALSE;
    }

  return pika_procedure_get_return_values (procedure, success,
                                           error ? *error : NULL);
}

static PikaValueArray *
drawables_close_popup_invoker (PikaProcedure         *procedure,
                               Pika                  *pika,
                               PikaContext           *context,
                               PikaProgress          *progress,
                               const PikaValueArray  *args,
                               GError               **error)
{
  gboolean success = TRUE;
  const gchar *callback;

  callback = g_value_get_string (pika_value_array_index (args, 0));

  if (success)
    {
      if (pika->no_interface ||
          ! pika_pdb_lookup_procedure (pika->pdb, callback) ||
          ! pika_pdb_dialog_close (pika, PIKA_TYPE_DRAWABLE, callback))
        success = FALSE;
    }

  return pika_procedure_get_return_values (procedure, success,
                                           error ? *error : NULL);
}

static PikaValueArray *
drawables_set_popup_invoker (PikaProcedure         *procedure,
                             Pika                  *pika,
                             PikaContext           *context,
                             PikaProgress          *progress,
                             const PikaValueArray  *args,
                             GError               **error)
{
  gboolean success = TRUE;
  const gchar *callback;
  PikaDrawable *drawable;

  callback = g_value_get_string (pika_value_array_index (args, 0));
  drawable = g_value_get_object (pika_value_array_index (args, 1));

  if (success)
    {
      if (pika->no_interface ||
          ! pika_pdb_lookup_procedure (pika->pdb, callback) ||
          ! pika_pdb_dialog_set (pika, PIKA_TYPE_DRAWABLE, callback, PIKA_OBJECT (drawable), NULL))
        success = FALSE;
    }

  return pika_procedure_get_return_values (procedure, success,
                                           error ? *error : NULL);
}

void
register_drawable_select_procs (PikaPDB *pdb)
{
  PikaProcedure *procedure;

  /*
   * pika-drawables-popup
   */
  procedure = pika_procedure_new (drawables_popup_invoker);
  pika_object_set_static_name (PIKA_OBJECT (procedure),
                               "pika-drawables-popup");
  pika_procedure_set_static_help (procedure,
                                  "Invokes the drawable selection dialog.",
                                  "Opens a dialog letting a user choose an drawable.",
                                  NULL);
  pika_procedure_set_static_attribution (procedure,
                                         "Jehan",
                                         "Jehan",
                                         "2023");
  pika_procedure_add_argument (procedure,
                               pika_param_spec_string ("callback",
                                                       "callback",
                                                       "The callback PDB proc to call when user chooses an drawable",
                                                       FALSE, FALSE, TRUE,
                                                       NULL,
                                                       PIKA_PARAM_READWRITE));
  pika_procedure_add_argument (procedure,
                               pika_param_spec_string ("popup-title",
                                                       "popup title",
                                                       "Title of the drawable selection dialog",
                                                       FALSE, FALSE, FALSE,
                                                       NULL,
                                                       PIKA_PARAM_READWRITE));
  pika_procedure_add_argument (procedure,
                               pika_param_spec_string ("drawable-type",
                                                       "drawable type",
                                                       "The name of the PIKA_TYPE_DRAWABLE subtype",
                                                       FALSE, FALSE, TRUE,
                                                       NULL,
                                                       PIKA_PARAM_READWRITE));
  pika_procedure_add_argument (procedure,
                               pika_param_spec_drawable ("initial-drawable",
                                                         "initial drawable",
                                                         "The drawable to set as the initial choice",
                                                         FALSE,
                                                         PIKA_PARAM_READWRITE | PIKA_PARAM_NO_VALIDATE));
  pika_procedure_add_argument (procedure,
                               g_param_spec_boxed ("parent-window",
                                                   "parent window",
                                                   "An optional parent window handle for the popup to be set transient to",
                                                   G_TYPE_BYTES,
                                                   PIKA_PARAM_READWRITE));
  pika_pdb_register_procedure (pdb, procedure);
  g_object_unref (procedure);

  /*
   * pika-drawables-close-popup
   */
  procedure = pika_procedure_new (drawables_close_popup_invoker);
  pika_object_set_static_name (PIKA_OBJECT (procedure),
                               "pika-drawables-close-popup");
  pika_procedure_set_static_help (procedure,
                                  "Close the drawable selection dialog.",
                                  "Closes an open drawable selection dialog.",
                                  NULL);
  pika_procedure_set_static_attribution (procedure,
                                         "Jehan",
                                         "Jehan",
                                         "2023");
  pika_procedure_add_argument (procedure,
                               pika_param_spec_string ("callback",
                                                       "callback",
                                                       "The name of the callback registered for this pop-up",
                                                       FALSE, FALSE, TRUE,
                                                       NULL,
                                                       PIKA_PARAM_READWRITE));
  pika_pdb_register_procedure (pdb, procedure);
  g_object_unref (procedure);

  /*
   * pika-drawables-set-popup
   */
  procedure = pika_procedure_new (drawables_set_popup_invoker);
  pika_object_set_static_name (PIKA_OBJECT (procedure),
                               "pika-drawables-set-popup");
  pika_procedure_set_static_help (procedure,
                                  "Sets the selected drawable in a drawable selection dialog.",
                                  "Sets the selected drawable in a drawable selection dialog.",
                                  NULL);
  pika_procedure_set_static_attribution (procedure,
                                         "Jehan",
                                         "Jehan",
                                         "2023");
  pika_procedure_add_argument (procedure,
                               pika_param_spec_string ("callback",
                                                       "callback",
                                                       "The name of the callback registered for this pop-up",
                                                       FALSE, FALSE, TRUE,
                                                       NULL,
                                                       PIKA_PARAM_READWRITE));
  pika_procedure_add_argument (procedure,
                               pika_param_spec_drawable ("drawable",
                                                         "drawable",
                                                         "The drawable to set as selected",
                                                         FALSE,
                                                         PIKA_PARAM_READWRITE | PIKA_PARAM_NO_VALIDATE));
  pika_pdb_register_procedure (pdb, procedure);
  g_object_unref (procedure);
}
