/* LIBPIKA - The PIKA Library
 * Copyright (C) 1995-1997 Peter Mattis and Spencer Kimball
 *
 * This library is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <https://www.gnu.org/licenses/>.
 */

#if !defined (__PIKA_UI_H_INSIDE__) && !defined (PIKA_COMPILATION)
#error "Only <libpika/pikaui.h> can be included directly."
#endif

#ifndef __PIKA_RESOURCE_CHOOSER_H__
#define __PIKA_RESOURCE_CHOOSER_H__

G_BEGIN_DECLS

#define PIKA_TYPE_RESOURCE_CHOOSER (pika_resource_chooser_get_type ())
G_DECLARE_DERIVABLE_TYPE (PikaResourceChooser, pika_resource_chooser, PIKA, RESOURCE_CHOOSER, GtkBox)

struct _PikaResourceChooserClass
{
  GtkBoxClass parent_class;

  /* Signals */
  void (* resource_set) (PikaResourceChooser *chooser,
                         PikaResource        *resource,
                         gboolean             dialog_closing);

  /* Abstract methods and class variables */
  void (*draw_interior) (PikaResourceChooser *chooser);

  GType resource_type;

  /* Padding for future expansion */
  gpointer padding[8];
};

PikaResource * pika_resource_chooser_get_resource     (PikaResourceChooser  *chooser);
void           pika_resource_chooser_set_resource     (PikaResourceChooser  *chooser,
                                                       PikaResource         *resource);
GtkWidget    * pika_resource_chooser_get_label        (PikaResourceChooser  *widget);


/* API from below, used by subclasses e.g. PikaBrushChooser */

void           pika_resource_chooser_set_drag_target  (PikaResourceChooser  *chooser,
                                                       GtkWidget            *drag_region_widget,
                                                       const GtkTargetEntry *drag_target);
void           pika_resource_chooser_set_clickable    (PikaResourceChooser  *chooser,
                                                       GtkWidget            *widget);

G_END_DECLS

#endif /* __PIKA_RESOURCE_CHOOSER_H__ */
